@@ -1,7 +1,7 @@
 aictab <-
   function(cand.set, modnames, sort = TRUE, c.hat = 1, second.ord = TRUE, nobs = NULL) {
     results <- NULL
-    known <- rep(0, 14) #create an identifier of class type other than lm, glm, multinom, polr, lme, gls, mer, unmarked, nls, or coxph
+    known <- 0
     ##extract classes
     mod.class <- unlist(lapply(X = cand.set, FUN = class))
     ##check if all are identical
@@ -11,21 +11,21 @@ aictab <-
     if(identical(check.class, "lm") || identical(check.class, c("glm", "lm"))) {
       results <- aictab.glm(cand.set = cand.set, modnames = modnames, sort = sort, c.hat = c.hat,
                             second.ord = second.ord, nobs = nobs)
-      known[1] <- 1
+      known <- 1
     }   
 
     ##determine if multinom
     if(identical(sort(check.class), c("multinom", "nnet"))) {
       results <- aictab.mult(cand.set = cand.set, modnames = modnames, sort = sort, c.hat = c.hat,
                              second.ord = second.ord, nobs = nobs)
-      known[2] <- 1
+      known <- 1
     }   
 
     ##determine if polr
     if(identical(check.class, "polr")) {
       results <- aictab.polr(cand.set = cand.set, modnames = modnames, sort = sort,
                              second.ord = second.ord, nobs = nobs)
-      known[3] <- 1
+      known <- 1
     }   
       
 
@@ -33,7 +33,7 @@ aictab <-
     if(identical(check.class, "lme"))  {
       results <- aictab.lme(cand.set = cand.set, modnames = modnames, sort = sort,
                             second.ord = second.ord, nobs = nobs)
-      known[4] <- 1
+      known <- 1
     }
 
 
@@ -41,7 +41,7 @@ aictab <-
     if(identical(check.class, "gls"))  {
       results <- aictab.gls(cand.set = cand.set, modnames = modnames, sort = sort,
                             second.ord = second.ord, nobs = nobs)
-      known[5] <- 1
+      known <- 1
     }
 
     
@@ -49,7 +49,7 @@ aictab <-
     if(identical(check.class, "mer"))  {
       results <- aictab.mer(cand.set = cand.set, modnames = modnames, sort = sort,
                             second.ord = second.ord, nobs = nobs)
-      known[6] <- 1
+      known <- 1
     }
 
 
@@ -59,7 +59,7 @@ aictab <-
     if(any(sapply(unmarked.class, FUN = function(i) identical(i, check.class)))) {
       results <- aictab.unmarked(cand.set = cand.set, modnames = modnames, sort = sort,
                                  c.hat = c.hat, second.ord = second.ord, nobs = nobs)
-      known[7] <- 1
+      known <- 1
     }
 
 
@@ -67,7 +67,7 @@ aictab <-
     if(identical(check.class, "nls"))  {
       results <- aictab.nls(cand.set = cand.set, modnames = modnames, sort = sort,
                             second.ord = second.ord, nobs = nobs)
-      known[8] <- 1
+      known <- 1
     }
 
 
@@ -75,7 +75,7 @@ aictab <-
     if(identical(check.class, "coxph") || identical(check.class, c("coxph.null", "coxph"))) {
       results <- aictab.coxph(cand.set = cand.set, modnames = modnames, sort = sort,
                               second.ord = second.ord, nobs = nobs)
-      known[9] <- 1
+      known <- 1
     }
 
     
@@ -83,28 +83,28 @@ aictab <-
     if(identical(check.class, c("rlm", "lm")))  {
       results <- aictab.rlm(cand.set = cand.set, modnames = modnames, sort = sort,
                             second.ord = second.ord, nobs = nobs)
-      known[10] <- 1
+      known <- 1
     }
 
     ##determine if clm
     if(identical(check.class, c("sclm", "clm")))  {
       results <- aictab.clm(cand.set = cand.set, modnames = modnames, sort = sort,
                             second.ord = second.ord, nobs = nobs)
-      known[11] <- 1
+      known <- 1
     }
 
     ##determine if clmm
     if(identical(check.class, "clmm"))  {
       results <- aictab.clmm(cand.set = cand.set, modnames = modnames, sort = sort,
                              second.ord = second.ord, nobs = nobs)
-      known[12] <- 1
+      known <- 1
     }
 
     ##determine if nlme
     if(identical(check.class, c("nlme", "lme")))  {
       results <- aictab.nlme(cand.set = cand.set, modnames = modnames, sort = sort,
                              second.ord = second.ord, nobs = nobs)
-      known[13] <- 1
+      known <- 1
     }
 
         
@@ -112,9 +112,15 @@ aictab <-
     if(identical(sort(check.class), c("lm", "lme"))) {
       stop("\nFunction not appropriate for mixture of object classes:", "\n",
                "avoid mixing objects of classes \'lm\' and \'lme\'\n")
-      known[14] <- 1
+      known <- 1
     }
 
+    ##determine if mer
+    if(identical(check.class, "lmerMod") || identical(check.class, "glmerMod") || identical(check.class, "nlmerMod"))  {
+      results <- aictab.merMod(cand.set = cand.set, modnames = modnames, sort = sort,
+                            second.ord = second.ord, nobs = nobs)
+      known <- 1
+    }
 
     
     ##warn if class is neither lm, glm, multinom, polr, lme, gls, nls, mer, nor unmarkedFit
