@@ -3,21 +3,21 @@ aictab.lme <-
 
     ##add check to see whether response variable is the same for all models
     check.resp <- lapply(X = cand.set, FUN = function(b) formula(b)[2])
-    if(length(unique(check.resp)) > 1) stop("You must use the same response variable for all models\n")
+    if(length(unique(check.resp)) > 1) stop("\nYou must use the same response variable for all models\n")
        
     Results <- NULL
 #check if models were fit with same method (REML or ML)
     check_ML <- unlist(lapply(cand.set, FUN = function(i) i$method))
     
     if (any(check_ML != "ML")) {
-      warning(paste("Model selection for fixed effects is only appropriate with method=ML:", "\n",
-                    "REML (default) should only be used to select random effects for a constant set of fixed effects"))
+      warning("\nModel selection for fixed effects is only appropriate with method=ML:", "\n",
+                    "REML (default) should only be used to select random effects for a constant set of fixed effects\n")
     }
     
     check.method <- unique(check_ML)
     
     if(identical(check.method, c("ML", "REML"))) {
-      stop("You should not have models fit with REML and ML in the same candidate model set")
+      stop("\nYou should not have models fit with REML and ML in the same candidate model set\n")
     }
     
     Results <- data.frame(Modnames = modnames)                    #assign model names to first column
